@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013, 2015 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,7 +53,6 @@ enum
 static void whiskermenu_config_dialog_delete(ConfigurationDialog* dialog)
 {
 	delete dialog;
-	dialog = NULL;
 }
 
 //-----------------------------------------------------------------------------
@@ -78,6 +77,7 @@ ConfigurationDialog::ConfigurationDialog(Plugin* plugin) :
 	GtkNotebook* notebook = GTK_NOTEBOOK(gtk_notebook_new());
 	gtk_notebook_append_page(notebook, init_appearance_tab(), gtk_label_new_with_mnemonic(_("_Appearance")));
 	gtk_notebook_append_page(notebook, init_behavior_tab(), gtk_label_new_with_mnemonic(_("_Behavior")));
+	gtk_notebook_append_page(notebook, init_commands_tab(), gtk_label_new_with_mnemonic(_("_Commands")));
 	gtk_notebook_append_page(notebook, init_search_actions_tab(), gtk_label_new_with_mnemonic(_("Search Actio_ns")));
 
 	// Add tabs to dialog
@@ -241,9 +241,17 @@ void ConfigurationDialog::toggle_position_categories_alternate(GtkToggleButton*
 
 //-----------------------------------------------------------------------------
 
+void ConfigurationDialog::recent_items_max_changed(GtkSpinButton* button)
+{
+	wm_settings->recent_items_max = gtk_spin_button_get_value_as_int(button);
+	wm_settings->set_modified();
+}
+
+//-----------------------------------------------------------------------------
+
 void ConfigurationDialog::toggle_remember_favorites(GtkToggleButton* button)
 {
-	wm_settings->favorites_in_recent = gtk_toggle_button_get_active(button);
+	wm_settings->favorites_in_recent = !gtk_toggle_button_get_active(button);
 	wm_settings->set_modified();
 }
 
@@ -257,6 +265,14 @@ void ConfigurationDialog::toggle_display_recent(GtkToggleButton* button)
 
 //-----------------------------------------------------------------------------
 
+void ConfigurationDialog::background_opacity_changed(GtkRange* range)
+{
+	wm_settings->menu_opacity = gtk_range_get_value(range);
+	wm_settings->set_modified();
+}
+
+//-----------------------------------------------------------------------------
+
 SearchAction* ConfigurationDialog::get_selected_action(GtkTreeIter* iter) const
 {
 	GtkTreeIter selected_iter;
@@ -456,127 +472,102 @@ void ConfigurationDialog::response(GtkDialog*, int response_id)
 
 GtkWidget* ConfigurationDialog::init_appearance_tab()
 {
-	// Create page
+	// Create appearance page
 	GtkWidget* page = gtk_alignment_new(0, 0, 1, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(page), 8);
 	GtkBox* contents_vbox = GTK_BOX(gtk_vbox_new(false, 0));
 	gtk_container_add(GTK_CONTAINER(page), GTK_WIDGET(contents_vbox));
 
+
 	// Create panel button section
-	GtkSizeGroup* label_size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
-	GtkBox* panel_vbox = GTK_BOX(gtk_vbox_new(false, 6));
-	GtkWidget* panel_frame = xfce_gtk_frame_box_new_with_content(_("Panel Button"), GTK_WIDGET(panel_vbox));
-	gtk_box_pack_start(contents_vbox, panel_frame, false, false, 0);
-	gtk_container_set_border_width(GTK_CONTAINER(panel_frame), 6);
+	GtkTable* panel_table = GTK_TABLE(gtk_table_new(4, 2, false));
+	gtk_table_set_col_spacings(panel_table, 12);
+	gtk_table_set_row_spacings(panel_table, 6);
+
+	GtkWidget* panel_frame = xfce_gtk_frame_box_new_with_content(_("Panel Button"), GTK_WIDGET(panel_table));
+	gtk_box_pack_start(contents_vbox, panel_frame, false, false, 6);
+	gtk_container_set_border_width(GTK_CONTAINER(panel_frame), 0);
 
 	// Add button style selector
-	GtkBox* hbox = GTK_BOX(gtk_hbox_new(false, 12));
-	gtk_box_pack_start(panel_vbox, GTK_WIDGET(hbox), false, false, 0);
-
 	GtkWidget* label = gtk_label_new_with_mnemonic(_("Di_splay:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
-	gtk_box_pack_start(hbox, label, false, false, 0);
-	gtk_size_group_add_widget(label_size_group, label);
+	gtk_table_attach(panel_table, label, 0, 1, 0, 1, GTK_FILL, GtkAttachOptions(GTK_EXPAND | GTK_FILL), 0, 0);
 
 	m_button_style = gtk_combo_box_text_new();
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(m_button_style), _("Icon"));
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(m_button_style), _("Title"));
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(m_button_style), _("Icon and title"));
 	gtk_combo_box_set_active(GTK_COMBO_BOX(m_button_style), static_cast<int>(m_plugin->get_button_style()) - 1);
-	gtk_box_pack_start(hbox, m_button_style, false, false, 0);
+	gtk_table_attach_defaults(panel_table, m_button_style, 1, 2, 0, 1);
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), m_button_style);
 	g_signal_connect_slot(m_button_style, "changed", &ConfigurationDialog::style_changed, this);
 
 	// Add title selector
-	hbox = GTK_BOX(gtk_hbox_new(false, 12));
-	gtk_box_pack_start(panel_vbox, GTK_WIDGET(hbox), false, false, 0);
-
 	label = gtk_label_new_with_mnemonic(_("_Title:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
-	gtk_box_pack_start(hbox, label, false, false, 0);
-	gtk_size_group_add_widget(label_size_group, label);
+	gtk_table_attach(panel_table, label, 0, 1, 1, 2, GTK_FILL, GtkAttachOptions(GTK_EXPAND | GTK_FILL), 0, 0);
 
 	m_title = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(m_title), m_plugin->get_button_title().c_str());
-	gtk_box_pack_start(hbox, m_title, true, true, 0);
+	gtk_table_attach_defaults(panel_table, m_title, 1, 2, 1, 2);
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), m_title);
 	g_signal_connect_slot(m_title, "changed", &ConfigurationDialog::title_changed, this);
 
 	// Add icon selector
-	hbox = GTK_BOX(gtk_hbox_new(false, 12));
-	gtk_box_pack_start(panel_vbox, GTK_WIDGET(hbox), false, false, 0);
-
 	label = gtk_label_new_with_mnemonic(_("_Icon:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
-	gtk_box_pack_start(hbox, label, false, false, 0);
-	gtk_size_group_add_widget(label_size_group, label);
+	gtk_table_attach(panel_table, label, 0, 1, 2, 3, GTK_FILL, GtkAttachOptions(GTK_EXPAND | GTK_FILL), 0, 0);
 
 	m_icon_button = gtk_button_new();
-	gtk_box_pack_start(hbox, m_icon_button, false, false, 0);
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), m_icon_button);
 	g_signal_connect_slot<GtkButton*>(m_icon_button, "clicked", &ConfigurationDialog::choose_icon, this);
+	GtkWidget* icon_alignment = gtk_alignment_new(0, 0, 0, 1);
+	gtk_container_add(GTK_CONTAINER(icon_alignment), m_icon_button);
+	gtk_table_attach_defaults(panel_table, icon_alignment, 1, 2, 2, 3);
 
 	m_icon = xfce_panel_image_new_from_source(m_plugin->get_button_icon_name().c_str());
 	xfce_panel_image_set_size(XFCE_PANEL_IMAGE(m_icon), 48);
 	gtk_container_add(GTK_CONTAINER(m_icon_button), m_icon);
 
-	m_button_single_row = gtk_check_button_new_with_mnemonic(_("Lay out icon in a single _panel row"));
-	gtk_box_pack_start(panel_vbox, m_button_single_row, true, true, 0);
+	m_button_single_row = gtk_check_button_new_with_mnemonic(_("Use a single _panel row"));
+	gtk_table_attach_defaults(panel_table, m_button_single_row, 1, 2, 3, 4);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_button_single_row), wm_settings->button_single_row);
 	gtk_widget_set_sensitive(m_button_single_row, gtk_combo_box_get_active(GTK_COMBO_BOX (m_button_style)) == 0);
 	g_signal_connect_slot(m_button_single_row, "toggled", &ConfigurationDialog::toggle_button_single_row, this);
+	gtk_widget_show(m_button_single_row);
+
 
 	// Create menu section
-	label_size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
-	GtkBox* appearance_vbox = GTK_BOX(gtk_vbox_new(false, 6));
-	GtkWidget* appearance_frame = xfce_gtk_frame_box_new_with_content(_("Menu"), GTK_WIDGET(appearance_vbox));
-	gtk_box_pack_start(contents_vbox, appearance_frame, false, false, 0);
-	gtk_container_set_border_width(GTK_CONTAINER(appearance_frame), 6);
+	GtkTable* menu_table = GTK_TABLE(gtk_table_new(6, 2, false));
+	gtk_table_set_col_spacings(menu_table, 12);
+	gtk_table_set_row_spacings(menu_table, 6);
+
+	GtkWidget* appearance_frame = xfce_gtk_frame_box_new_with_content(_("Menu"), GTK_WIDGET(menu_table));
+	gtk_box_pack_start(contents_vbox, appearance_frame, false, false, 6);
+	gtk_container_set_border_width(GTK_CONTAINER(appearance_frame), 0);
 
 	// Add option to use generic names
 	m_show_generic_names = gtk_check_button_new_with_mnemonic(_("Show generic application _names"));
-	gtk_box_pack_start(appearance_vbox, m_show_generic_names, true, true, 0);
+	gtk_table_attach_defaults(menu_table, m_show_generic_names, 0, 2, 0, 1);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_show_generic_names), !wm_settings->launcher_show_name);
 	g_signal_connect_slot(m_show_generic_names, "toggled", &ConfigurationDialog::toggle_show_generic_name, this);
 
 	// Add option to hide descriptions
 	m_show_descriptions = gtk_check_button_new_with_mnemonic(_("Show application _descriptions"));
-	gtk_box_pack_start(appearance_vbox, m_show_descriptions, true, true, 0);
+	gtk_table_attach_defaults(menu_table, m_show_descriptions, 0, 2, 1, 2);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_show_descriptions), wm_settings->launcher_show_description);
 	g_signal_connect_slot(m_show_descriptions, "toggled", &ConfigurationDialog::toggle_show_description, this);
 
 	// Add option to show menu hierarchy
 	m_show_hierarchy = gtk_check_button_new_with_mnemonic(_("Show menu hie_rarchy"));
-	gtk_box_pack_start(appearance_vbox, m_show_hierarchy, true, true, 0);
+	gtk_table_attach_defaults(menu_table, m_show_hierarchy, 0, 2, 2, 3);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_show_hierarchy), wm_settings->load_hierarchy);
 	g_signal_connect_slot(m_show_hierarchy, "toggled", &ConfigurationDialog::toggle_show_hierarchy, this);
 
-	// Add option to use alternate search entry position
-	m_position_search_alternate = gtk_check_button_new_with_mnemonic(_("Position _search entry next to panel button"));
-	gtk_box_pack_start(appearance_vbox, m_position_search_alternate, true, true, 0);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_position_search_alternate), wm_settings->position_search_alternate);
-	g_signal_connect_slot(m_position_search_alternate, "toggled", &ConfigurationDialog::toggle_position_search_alternate, this);
-
-	// Add option to use alternate commands position
-	m_position_commands_alternate = gtk_check_button_new_with_mnemonic(_("Position commands next to search _entry"));
-	gtk_box_pack_start(appearance_vbox, m_position_commands_alternate, true, true, 0);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_position_commands_alternate), wm_settings->position_commands_alternate);
-	gtk_widget_set_sensitive(GTK_WIDGET(m_position_commands_alternate), wm_settings->position_search_alternate);
-	g_signal_connect_slot(m_position_commands_alternate, "toggled", &ConfigurationDialog::toggle_position_commands_alternate, this);
-
-	// Add option to use alternate categories position
-	m_position_categories_alternate = gtk_check_button_new_with_mnemonic(_("Position cate_gories next to panel button"));
-	gtk_box_pack_start(appearance_vbox, m_position_categories_alternate, true, true, 0);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_position_categories_alternate), wm_settings->position_categories_alternate);
-	g_signal_connect_slot(m_position_categories_alternate, "toggled", &ConfigurationDialog::toggle_position_categories_alternate, this);
-
 	// Add item icon size selector
-	hbox = GTK_BOX(gtk_hbox_new(false, 12));
-	gtk_box_pack_start(appearance_vbox, GTK_WIDGET(hbox), false, false, 0);
-
 	label = gtk_label_new_with_mnemonic(_("Ite_m icon size:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
-	gtk_box_pack_start(hbox, label, false, false, 0);
-	gtk_size_group_add_widget(label_size_group, label);
+	gtk_table_attach(menu_table, label, 0, 1, 3, 4, GTK_FILL, GtkAttachOptions(GTK_EXPAND | GTK_FILL), 0, 0);
 
 	m_item_icon_size = gtk_combo_box_text_new();
 	std::vector<std::string> icon_sizes = IconSize::get_strings();
@@ -585,18 +576,14 @@ GtkWidget* ConfigurationDialog::init_appearance_tab()
 		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(m_item_icon_size), i->c_str());
 	}
 	gtk_combo_box_set_active(GTK_COMBO_BOX(m_item_icon_size), wm_settings->launcher_icon_size + 1);
-	gtk_box_pack_start(hbox, m_item_icon_size, false, false, 0);
+	gtk_table_attach_defaults(menu_table, m_item_icon_size, 1, 2, 3, 4);
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), m_item_icon_size);
 	g_signal_connect_slot(m_item_icon_size, "changed", &ConfigurationDialog::item_icon_size_changed, this);
 
 	// Add category icon size selector
-	hbox = GTK_BOX(gtk_hbox_new(false, 12));
-	gtk_box_pack_start(appearance_vbox, GTK_WIDGET(hbox), false, false, 0);
-
 	label = gtk_label_new_with_mnemonic(_("Categ_ory icon size:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
-	gtk_box_pack_start(hbox, label, false, false, 0);
-	gtk_size_group_add_widget(label_size_group, label);
+	gtk_table_attach(menu_table, label, 0, 1, 4, 5, GTK_FILL, GtkAttachOptions(GTK_EXPAND | GTK_FILL), 0, 0);
 
 	m_category_icon_size = gtk_combo_box_text_new();
 	for (std::vector<std::string>::const_iterator i = icon_sizes.begin(), end = icon_sizes.end(); i != end; ++i)
@@ -604,10 +591,21 @@ GtkWidget* ConfigurationDialog::init_appearance_tab()
 		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(m_category_icon_size), i->c_str());
 	}
 	gtk_combo_box_set_active(GTK_COMBO_BOX(m_category_icon_size), wm_settings->category_icon_size + 1);
-	gtk_box_pack_start(hbox, m_category_icon_size, false, false, 0);
+	gtk_table_attach_defaults(menu_table, m_category_icon_size, 1, 2, 4, 5);
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), m_category_icon_size);
 	g_signal_connect_slot(m_category_icon_size, "changed", &ConfigurationDialog::category_icon_size_changed, this);
 
+	// Add option to control background opacity
+	label = gtk_label_new_with_mnemonic(_("Background opacit_y:"));
+	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_table_attach(menu_table, label, 0, 1, 5, 6, GTK_FILL, GtkAttachOptions(GTK_EXPAND | GTK_FILL), 0, 0);
+
+	m_background_opacity = gtk_hscale_new_with_range(0.0, 100.0, 1.0);
+	gtk_table_attach_defaults(menu_table, m_background_opacity, 1, 2, 5, 6);
+	gtk_scale_set_value_pos(GTK_SCALE(m_background_opacity), GTK_POS_RIGHT);
+	gtk_range_set_value(GTK_RANGE(m_background_opacity), wm_settings->menu_opacity);
+	g_signal_connect_slot(m_background_opacity, "value-changed", &ConfigurationDialog::background_opacity_changed, this);
+
 	return page;
 }
 
@@ -615,11 +613,18 @@ GtkWidget* ConfigurationDialog::init_appearance_tab()
 
 GtkWidget* ConfigurationDialog::init_behavior_tab()
 {
-	// Create behavior section
+	// Create behavior page
 	GtkWidget* page = gtk_alignment_new(0, 0, 1, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(page), 8);
-	GtkBox* behavior_vbox = GTK_BOX(gtk_vbox_new(false, 8));
-	gtk_container_add(GTK_CONTAINER(page), GTK_WIDGET(behavior_vbox));
+	GtkBox* contents_vbox = GTK_BOX(gtk_vbox_new(false, 8));
+	gtk_container_add(GTK_CONTAINER(page), GTK_WIDGET(contents_vbox));
+
+
+	// Create menu section
+	GtkBox* behavior_vbox = GTK_BOX(gtk_vbox_new(false, 6));
+	GtkWidget* behavior_frame = xfce_gtk_frame_box_new_with_content(_("Menu"), GTK_WIDGET(behavior_vbox));
+	gtk_box_pack_start(contents_vbox, behavior_frame, false, false, 6);
+	gtk_container_set_border_width(GTK_CONTAINER(behavior_frame), 0);
 
 	// Add option to switch categories by hovering
 	m_hover_switch_category = gtk_check_button_new_with_mnemonic(_("Switch categories by _hovering"));
@@ -627,24 +632,71 @@ GtkWidget* ConfigurationDialog::init_behavior_tab()
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_hover_switch_category), wm_settings->category_hover_activate);
 	g_signal_connect_slot(m_hover_switch_category, "toggled", &ConfigurationDialog::toggle_hover_switch_category, this);
 
+	// Add option to use alternate search entry position
+	m_position_search_alternate = gtk_check_button_new_with_mnemonic(_("Position _search entry next to panel button"));
+	gtk_box_pack_start(behavior_vbox, m_position_search_alternate, true, true, 0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_position_search_alternate), wm_settings->position_search_alternate);
+	g_signal_connect_slot(m_position_search_alternate, "toggled", &ConfigurationDialog::toggle_position_search_alternate, this);
+
+	// Add option to use alternate commands position
+	m_position_commands_alternate = gtk_check_button_new_with_mnemonic(_("Position commands next to search _entry"));
+	gtk_box_pack_start(behavior_vbox, m_position_commands_alternate, true, true, 0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_position_commands_alternate), wm_settings->position_commands_alternate);
+	gtk_widget_set_sensitive(GTK_WIDGET(m_position_commands_alternate), wm_settings->position_search_alternate);
+	g_signal_connect_slot(m_position_commands_alternate, "toggled", &ConfigurationDialog::toggle_position_commands_alternate, this);
+
+	// Add option to use alternate categories position
+	m_position_categories_alternate = gtk_check_button_new_with_mnemonic(_("Position cate_gories next to panel button"));
+	gtk_box_pack_start(behavior_vbox, m_position_categories_alternate, true, true, 0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_position_categories_alternate), wm_settings->position_categories_alternate);
+	g_signal_connect_slot(m_position_categories_alternate, "toggled", &ConfigurationDialog::toggle_position_categories_alternate, this);
+
+
+	// Create recently used section
+	GtkTable* recent_table = GTK_TABLE(gtk_table_new(3, 2, false));
+	gtk_table_set_col_spacings(recent_table, 12);
+	gtk_table_set_row_spacings(recent_table, 6);
+
+	GtkWidget* recent_frame = xfce_gtk_frame_box_new_with_content(_("Recently Used"), GTK_WIDGET(recent_table));
+	gtk_box_pack_start(contents_vbox, recent_frame, false, false, 6);
+	gtk_container_set_border_width(GTK_CONTAINER(recent_frame), 0);
+
+	// Add value to change maximum number of recently used entries
+	GtkWidget* label = gtk_label_new_with_mnemonic(_("Amount of _items:"));
+	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_table_attach(recent_table, label, 0, 1, 0, 1, GTK_FILL, GtkAttachOptions(GTK_EXPAND | GTK_FILL), 0, 0);
+
+	m_recent_items_max = gtk_spin_button_new_with_range(5, 100, 1);
+	gtk_table_attach_defaults(recent_table, m_recent_items_max, 1, 2, 0, 1);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), m_recent_items_max);
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_recent_items_max), wm_settings->recent_items_max);
+	g_signal_connect_slot(m_recent_items_max, "value-changed", &ConfigurationDialog::recent_items_max_changed, this);
+
 	// Add option to remember favorites
-	m_remember_favorites = gtk_check_button_new_with_mnemonic(_("Include _favorites in recently used"));
-	gtk_box_pack_start(behavior_vbox, m_remember_favorites, true, true, 0);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_remember_favorites), wm_settings->favorites_in_recent);
+	m_remember_favorites = gtk_check_button_new_with_mnemonic(_("Ignore _favorites"));
+	gtk_table_attach_defaults(recent_table, m_remember_favorites, 0, 2, 1, 2);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_remember_favorites), !wm_settings->favorites_in_recent);
 	g_signal_connect_slot(m_remember_favorites, "toggled", &ConfigurationDialog::toggle_remember_favorites, this);
 
 	// Add option to display recently used
-	m_display_recent = gtk_check_button_new_with_mnemonic(_("Display recently _used by default"));
-	gtk_box_pack_start(behavior_vbox, m_display_recent, true, true, 0);
+	m_display_recent = gtk_check_button_new_with_mnemonic(_("Display by _default"));
+	gtk_table_attach_defaults(recent_table, m_display_recent, 0, 2, 2, 3);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_display_recent), wm_settings->display_recent);
 	g_signal_connect_slot(m_display_recent, "toggled", &ConfigurationDialog::toggle_display_recent, this);
 
-	// Create commands section
+	return page;
+}
+
+//-----------------------------------------------------------------------------
+
+GtkWidget* ConfigurationDialog::init_commands_tab()
+{
+	// Create commands page
+	GtkWidget* page = gtk_alignment_new(0, 0, 1, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(page), 8);
+	GtkBox* commands_vbox = GTK_BOX(gtk_vbox_new(false, 8));
+	gtk_container_add(GTK_CONTAINER(page), GTK_WIDGET(commands_vbox));
 	GtkSizeGroup* label_size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
-	GtkBox* commands_vbox = GTK_BOX(gtk_vbox_new(false, 6));
-	GtkWidget* commands_frame = xfce_gtk_frame_box_new_with_content(_("Commands"), GTK_WIDGET(commands_vbox));
-	gtk_box_pack_start(behavior_vbox, commands_frame, false, false, 6);
-	gtk_container_set_border_width(GTK_CONTAINER(commands_frame), 0);
 
 	// Add command entries
 	for (int i = 0; i < Settings::CountCommands; ++i)
@@ -661,7 +713,7 @@ GtkWidget* ConfigurationDialog::init_behavior_tab()
 
 GtkWidget* ConfigurationDialog::init_search_actions_tab()
 {
-	// Create search actions section
+	// Create search actions page
 	GtkWidget* page = gtk_alignment_new(0, 0, 1, 1);
 	gtk_container_set_border_width(GTK_CONTAINER(page), 8);
 	GtkTable* actions_table = GTK_TABLE(gtk_table_new(3, 2, false));
